antares.apps.client.models package
==================================

Submodules
----------

antares.apps.client.models.address\_item module
-----------------------------------------------

.. automodule:: antares.apps.client.models.address_item
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.attribute\_definition module
-------------------------------------------------------

.. automodule:: antares.apps.client.models.attribute_definition
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client module
----------------------------------------

.. automodule:: antares.apps.client.models.client
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client\_attribute module
---------------------------------------------------

.. automodule:: antares.apps.client.models.client_attribute
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client\_branch module
------------------------------------------------

.. automodule:: antares.apps.client.models.client_branch
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client\_business\_classification module
------------------------------------------------------------------

.. automodule:: antares.apps.client.models.client_business_classification
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client\_identification\_type module
--------------------------------------------------------------

.. automodule:: antares.apps.client.models.client_identification_type
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client\_type module
----------------------------------------------

.. automodule:: antares.apps.client.models.client_type
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client\_user\_relation module
--------------------------------------------------------

.. automodule:: antares.apps.client.models.client_user_relation
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.client\_user\_relation\_permission module
--------------------------------------------------------------------

.. automodule:: antares.apps.client.models.client_user_relation_permission
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.email\_item module
---------------------------------------------

.. automodule:: antares.apps.client.models.email_item
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.identification\_item module
------------------------------------------------------

.. automodule:: antares.apps.client.models.identification_item
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.isic\_position module
------------------------------------------------

.. automodule:: antares.apps.client.models.isic_position
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.social\_network\_item module
-------------------------------------------------------

.. automodule:: antares.apps.client.models.social_network_item
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.client.models.telephone\_item module
-------------------------------------------------

.. automodule:: antares.apps.client.models.telephone_item
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.client.models
   :members:
   :undoc-members:
   :show-inheritance:
